/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.giraph.writable.kryo;

import java.io.DataOutput;
import java.io.IOException;
import java.io.OutputStream;

/**
 * Thin wrapper around a DataOutput so it can be used as an
 * {@link java.io.OutputStream}
 *
 * For use with {@link com.esotericsoftware.kryo.io.Output})
 */
public class DataOutputWrapperStream extends OutputStream {
  /** Wrapped DataOutput object */
  private DataOutput out;

  public void setDataOutput(DataOutput out) {
    this.out = out;
  }

  @Override
  public void write(int b) throws IOException {
    out.write(b);
  }

  @Override
  public void write(byte[] b, int off, int len) throws IOException {
    out.write(b, off, len);
  }
}
